==> php-8.3.29.tar.xz: php-8.3.29/main/main.stub.php <==
<?php

/** @generate-class-entries */

/* Register constants */
/**
 * @var string
 * @cvalue PHP_VERSION
 */
const PHP_VERSION = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_MAJOR_VERSION
 */
const PHP_MAJOR_VERSION = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_MINOR_VERSION
 */
const PHP_MINOR_VERSION = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_RELEASE_VERSION
 */
const PHP_RELEASE_VERSION = UNKNOWN;
	
/**
 * @var string
 * @cvalue PHP_EXTRA_VERSION
 */
const PHP_EXTRA_VERSION = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_VERSION_ID
 */
const PHP_VERSION_ID = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_ZTS
 */
const PHP_ZTS = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_DEBUG
 */
const PHP_DEBUG = UNKNOWN;
/**
 * @var string
 * @cvalue PHP_OS_STR
 */
const PHP_OS = UNKNOWN;
/**
 * @var string
 * @cvalue PHP_OS_FAMILY
 */
const PHP_OS_FAMILY = UNKNOWN;
/**
 * @var string
 * @cvalue PHP_INCLUDE_PATH
 */
const DEFAULT_INCLUDE_PATH = UNKNOWN;
/**
 * @var string
 * @cvalue PEAR_INSTALLDIR
 */
const PEAR_INSTALL_DIR = UNKNOWN;
/**
 * @var string
 * @cvalue PHP_EXTENSION_DIR
 */
const PEAR_EXTENSION_DIR = UNKNOWN;
/**
 * @var string
 * @cvalue PHP_EXTENSION_DIR
 */
const PHP_EXTENSION_DIR = UNKNOWN;
/**
 * @var string
 * @cvalue PHP_PREFIX
 */
const PHP_PREFIX = UNKNOWN;
/**
 * @var string
 * @cvalue PHP_BINDIR
 */
const PHP_BINDIR = UNKNOWN;
#ifndef PHP_WIN32
/**
 * @var string
 * @cvalue PHP_MANDIR
 */
const PHP_MANDIR = UNKNOWN;
#endif
/**
 * @var string
 * @cvalue PHP_LIBDIR
 */
const PHP_LIBDIR = UNKNOWN;
/**
 * @var string
 * @cvalue PHP_DATADIR
 */
const PHP_DATADIR = UNKNOWN;
/**
 * @var string
 * @cvalue PHP_SYSCONFDIR
 */
const PHP_SYSCONFDIR = UNKNOWN;
/**
 * @var string
 * @cvalue PHP_LOCALSTATEDIR
 */
const PHP_LOCALSTATEDIR = UNKNOWN;
/**
 * @var string
 * @cvalue PHP_CONFIG_FILE_PATH
 */
const PHP_CONFIG_FILE_PATH = UNKNOWN;
/**
 * @var string
 * @cvalue PHP_CONFIG_FILE_SCAN_DIR
 */
const PHP_CONFIG_FILE_SCAN_DIR = UNKNOWN;
/**
 * @var string
 * @cvalue PHP_SHLIB_SUFFIX
 */
const PHP_SHLIB_SUFFIX = UNKNOWN;
/**
 * @var string
 * @cvalue PHP_EOL
 */
const PHP_EOL = UNKNOWN;
/**
 * @var int
 * @cvalue MAXPATHLEN
 */
const PHP_MAXPATHLEN = UNKNOWN;
/**
 * @var int
 * @cvalue ZEND_LONG_MAX
 */
const PHP_INT_MAX = UNKNOWN;
/**
 * @var int
 * @cvalue ZEND_LONG_MIN
 */
const PHP_INT_MIN = UNKNOWN;
/**
 * @var int
 * @cvalue SIZEOF_ZEND_LONG
 */
const PHP_INT_SIZE = UNKNOWN;
/**
 * @var int
 * @cvalue FD_SETSIZE
 */
const PHP_FD_SETSIZE = UNKNOWN;
/**
 * @var int
 * @cvalue DBL_DIG
 */
const PHP_FLOAT_DIG = UNKNOWN;
/**
 * @var float
 * @cvalue DBL_EPSILON
 */
const PHP_FLOAT_EPSILON = UNKNOWN;
/**
 * @var float
 * @cvalue DBL_MAX
 */
const PHP_FLOAT_MAX = UNKNOWN;
/**
 * @var float
 * @cvalue DBL_MIN
 */
const PHP_FLOAT_MIN = UNKNOWN;

#ifdef PHP_WIN32
/**
 * @var int
 * @cvalue EG(windows_version_info).dwMajorVersion
 */
const PHP_WINDOWS_VERSION_MAJOR = UNKNOWN;
/**
 * @var int
 * @cvalue EG(windows_version_info).dwMinorVersion
 */
const PHP_WINDOWS_VERSION_MINOR = UNKNOWN;
/**
 * @var int
 * @cvalue EG(windows_version_info).dwBuildNumber
 */
const PHP_WINDOWS_VERSION_BUILD = UNKNOWN;
/**
 * @var int
 * @cvalue EG(windows_version_info).dwPlatformId
 */
const PHP_WINDOWS_VERSION_PLATFORM = UNKNOWN;
/**
 * @var int
 * @cvalue EG(windows_version_info).wServicePackMajor
 */
const PHP_WINDOWS_VERSION_SP_MAJOR = UNKNOWN;
/**
 * @var int
 * @cvalue EG(windows_version_info).wServicePackMinor
 */
const PHP_WINDOWS_VERSION_SP_MINOR = UNKNOWN;
/**
 * @var int
 * @cvalue EG(windows_version_info).wSuiteMask
 */
const PHP_WINDOWS_VERSION_SUITEMASK = UNKNOWN;
/**
 * @var int
 * @cvalue EG(windows_version_info).wProductType
 */
const PHP_WINDOWS_VERSION_PRODUCTTYPE = UNKNOWN;
/**
 * @var int
 * @cvalue VER_NT_DOMAIN_CONTROLLER
 */
const PHP_WINDOWS_NT_DOMAIN_CONTROLLER = UNKNOWN;
/**
 * @var int
 * @cvalue VER_NT_SERVER
 */
const PHP_WINDOWS_NT_SERVER = UNKNOWN;
/**
 * @var int
 * @cvalue VER_NT_WORKSTATION
 */
const PHP_WINDOWS_NT_WORKSTATION = UNKNOWN;
#endif

/**
 * @var int
 * @cvalue PHP_OUTPUT_HANDLER_START
 */
const PHP_OUTPUT_HANDLER_START = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_OUTPUT_HANDLER_WRITE
 */
const PHP_OUTPUT_HANDLER_WRITE = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_OUTPUT_HANDLER_FLUSH
 */
const PHP_OUTPUT_HANDLER_FLUSH = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_OUTPUT_HANDLER_CLEAN
 */
const PHP_OUTPUT_HANDLER_CLEAN = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_OUTPUT_HANDLER_FINAL
 */
const PHP_OUTPUT_HANDLER_FINAL = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_OUTPUT_HANDLER_WRITE
 */
const PHP_OUTPUT_HANDLER_CONT = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_OUTPUT_HANDLER_FINAL
 */
const PHP_OUTPUT_HANDLER_END = UNKNOWN;

/**
 * @var int
 * @cvalue PHP_OUTPUT_HANDLER_CLEANABLE
 */
const PHP_OUTPUT_HANDLER_CLEANABLE = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_OUTPUT_HANDLER_FLUSHABLE
 */
const PHP_OUTPUT_HANDLER_FLUSHABLE = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_OUTPUT_HANDLER_REMOVABLE
 */
const PHP_OUTPUT_HANDLER_REMOVABLE = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_OUTPUT_HANDLER_STDFLAGS
 */
const PHP_OUTPUT_HANDLER_STDFLAGS = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_OUTPUT_HANDLER_STARTED
 */
const PHP_OUTPUT_HANDLER_STARTED = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_OUTPUT_HANDLER_DISABLED
 */
const PHP_OUTPUT_HANDLER_DISABLED = UNKNOWN;

/**
 * @var int
 * @cvalue PHP_UPLOAD_ERROR_OK
 */
const UPLOAD_ERR_OK = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_UPLOAD_ERROR_A
 */
const UPLOAD_ERR_INI_SIZE = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_UPLOAD_ERROR_B
 */
const UPLOAD_ERR_FORM_SIZE = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_UPLOAD_ERROR_C
 */
const UPLOAD_ERR_PARTIAL = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_UPLOAD_ERROR_D
 */
const UPLOAD_ERR_NO_FILE = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_UPLOAD_ERROR_E
 */
const UPLOAD_ERR_NO_TMP_DIR = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_UPLOAD_ERROR_F
 */
const UPLOAD_ERR_CANT_WRITE = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_UPLOAD_ERROR_X
 */
const UPLOAD_ERR_EXTENSION = UNKNOWN;

==> php-8.4.17.tar.xz: php-8.4.17/main/main.stub.php <==
<?php

/** @generate-class-entries */

/* Register constants */
/**
 * @var string
 * @cvalue PHP_VERSION
 */
const PHP_VERSION = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_MAJOR_VERSION
 */
const PHP_MAJOR_VERSION = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_MINOR_VERSION
 */
const PHP_MINOR_VERSION = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_RELEASE_VERSION
 */
const PHP_RELEASE_VERSION = UNKNOWN;

/**
 * @var string
 * @cvalue PHP_EXTRA_VERSION
 */
const PHP_EXTRA_VERSION = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_VERSION_ID
 */
const PHP_VERSION_ID = UNKNOWN;
/**
 * @var bool
 * @cvalue PHP_ZTS
 */
const PHP_ZTS = UNKNOWN;
/**
 * @var bool
 * @cvalue PHP_DEBUG
 */
const PHP_DEBUG = UNKNOWN;
/**
 * @var string
 * @cvalue PHP_OS_STR
 */
const PHP_OS = UNKNOWN;
/**
 * @var string
 * @cvalue PHP_OS_FAMILY
 */
const PHP_OS_FAMILY = UNKNOWN;
/**
 * @var string
 * @cvalue PHP_INCLUDE_PATH
 */
const DEFAULT_INCLUDE_PATH = UNKNOWN;
/**
 * @var string
 * @cvalue PEAR_INSTALLDIR
 */
const PEAR_INSTALL_DIR = UNKNOWN;
/**
 * @var string
 * @cvalue PHP_EXTENSION_DIR
 */
const PEAR_EXTENSION_DIR = UNKNOWN;
/**
 * @var string
 * @cvalue PHP_EXTENSION_DIR
 */
const PHP_EXTENSION_DIR = UNKNOWN;
/**
 * @var string
 * @cvalue PHP_PREFIX
 */
const PHP_PREFIX = UNKNOWN;
/**
 * @var string
 * @cvalue PHP_BINDIR
 */
const PHP_BINDIR = UNKNOWN;
/**
 * @var string
 * @cvalue PHP_SBINDIR
 */
const PHP_SBINDIR = UNKNOWN;
#ifndef PHP_WIN32
/**
 * @var string
 * @cvalue PHP_MANDIR
 */
const PHP_MANDIR = UNKNOWN;
#endif
/**
 * @var string
 * @cvalue PHP_LIBDIR
 */
const PHP_LIBDIR = UNKNOWN;
/**
 * @var string
 * @cvalue PHP_DATADIR
 */
const PHP_DATADIR = UNKNOWN;
/**
 * @var string
 * @cvalue PHP_SYSCONFDIR
 */
const PHP_SYSCONFDIR = UNKNOWN;
/**
 * @var string
 * @cvalue PHP_LOCALSTATEDIR
 */
const PHP_LOCALSTATEDIR = UNKNOWN;
/**
 * @var string
 * @cvalue PHP_CONFIG_FILE_PATH
 */
const PHP_CONFIG_FILE_PATH = UNKNOWN;
/**
 * @var string
 * @cvalue PHP_CONFIG_FILE_SCAN_DIR
 */
const PHP_CONFIG_FILE_SCAN_DIR = UNKNOWN;
/**
 * @var string
 * @cvalue PHP_SHLIB_SUFFIX
 */
const PHP_SHLIB_SUFFIX = UNKNOWN;
/**
 * @var string
 * @cvalue PHP_EOL
 */
const PHP_EOL = UNKNOWN;
/**
 * @var int
 * @cvalue MAXPATHLEN
 */
const PHP_MAXPATHLEN = UNKNOWN;
/**
 * @var int
 * @cvalue ZEND_LONG_MAX
 */
const PHP_INT_MAX = UNKNOWN;
/**
 * @var int
 * @cvalue ZEND_LONG_MIN
 */
const PHP_INT_MIN = UNKNOWN;
/**
 * @var int
 * @cvalue SIZEOF_ZEND_LONG
 */
const PHP_INT_SIZE = UNKNOWN;
/**
 * @var int
 * @cvalue FD_SETSIZE
 */
const PHP_FD_SETSIZE = UNKNOWN;
/**
 * @var int
 * @cvalue DBL_DIG
 */
const PHP_FLOAT_DIG = UNKNOWN;
/**
 * @var float
 * @cvalue DBL_EPSILON
 */
const PHP_FLOAT_EPSILON = UNKNOWN;
/**
 * @var float
 * @cvalue DBL_MAX
 */
const PHP_FLOAT_MAX = UNKNOWN;
/**
 * @var float
 * @cvalue DBL_MIN
 */
const PHP_FLOAT_MIN = UNKNOWN;

#ifdef PHP_WIN32
/**
 * @var int
 * @cvalue EG(windows_version_info).dwMajorVersion
 */
const PHP_WINDOWS_VERSION_MAJOR = UNKNOWN;
/**
 * @var int
 * @cvalue EG(windows_version_info).dwMinorVersion
 */
const PHP_WINDOWS_VERSION_MINOR = UNKNOWN;
/**
 * @var int
 * @cvalue EG(windows_version_info).dwBuildNumber
 */
const PHP_WINDOWS_VERSION_BUILD = UNKNOWN;
/**
 * @var int
 * @cvalue EG(windows_version_info).dwPlatformId
 */
const PHP_WINDOWS_VERSION_PLATFORM = UNKNOWN;
/**
 * @var int
 * @cvalue EG(windows_version_info).wServicePackMajor
 */
const PHP_WINDOWS_VERSION_SP_MAJOR = UNKNOWN;
/**
 * @var int
 * @cvalue EG(windows_version_info).wServicePackMinor
 */
const PHP_WINDOWS_VERSION_SP_MINOR = UNKNOWN;
/**
 * @var int
 * @cvalue EG(windows_version_info).wSuiteMask
 */
const PHP_WINDOWS_VERSION_SUITEMASK = UNKNOWN;
/**
 * @var int
 * @cvalue EG(windows_version_info).wProductType
 */
const PHP_WINDOWS_VERSION_PRODUCTTYPE = UNKNOWN;
/**
 * @var int
 * @cvalue VER_NT_DOMAIN_CONTROLLER
 */
const PHP_WINDOWS_NT_DOMAIN_CONTROLLER = UNKNOWN;
/**
 * @var int
 * @cvalue VER_NT_SERVER
 */
const PHP_WINDOWS_NT_SERVER = UNKNOWN;
/**
 * @var int
 * @cvalue VER_NT_WORKSTATION
 */
const PHP_WINDOWS_NT_WORKSTATION = UNKNOWN;
#endif

/**
 * @var int
 * @cvalue PHP_OUTPUT_HANDLER_START
 */
const PHP_OUTPUT_HANDLER_START = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_OUTPUT_HANDLER_WRITE
 */
const PHP_OUTPUT_HANDLER_WRITE = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_OUTPUT_HANDLER_FLUSH
 */
const PHP_OUTPUT_HANDLER_FLUSH = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_OUTPUT_HANDLER_CLEAN
 */
const PHP_OUTPUT_HANDLER_CLEAN = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_OUTPUT_HANDLER_FINAL
 */
const PHP_OUTPUT_HANDLER_FINAL = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_OUTPUT_HANDLER_WRITE
 */
const PHP_OUTPUT_HANDLER_CONT = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_OUTPUT_HANDLER_FINAL
 */
const PHP_OUTPUT_HANDLER_END = UNKNOWN;

/**
 * @var int
 * @cvalue PHP_OUTPUT_HANDLER_CLEANABLE
 */
const PHP_OUTPUT_HANDLER_CLEANABLE = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_OUTPUT_HANDLER_FLUSHABLE
 */
const PHP_OUTPUT_HANDLER_FLUSHABLE = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_OUTPUT_HANDLER_REMOVABLE
 */
const PHP_OUTPUT_HANDLER_REMOVABLE = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_OUTPUT_HANDLER_STDFLAGS
 */
const PHP_OUTPUT_HANDLER_STDFLAGS = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_OUTPUT_HANDLER_STARTED
 */
const PHP_OUTPUT_HANDLER_STARTED = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_OUTPUT_HANDLER_DISABLED
 */
const PHP_OUTPUT_HANDLER_DISABLED = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_OUTPUT_HANDLER_PROCESSED
 */
const PHP_OUTPUT_HANDLER_PROCESSED = UNKNOWN;

/**
 * @var int
 * @cvalue PHP_UPLOAD_ERROR_OK
 */
const UPLOAD_ERR_OK = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_UPLOAD_ERROR_A
 */
const UPLOAD_ERR_INI_SIZE = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_UPLOAD_ERROR_B
 */
const UPLOAD_ERR_FORM_SIZE = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_UPLOAD_ERROR_C
 */
const UPLOAD_ERR_PARTIAL = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_UPLOAD_ERROR_D
 */
const UPLOAD_ERR_NO_FILE = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_UPLOAD_ERROR_E
 */
const UPLOAD_ERR_NO_TMP_DIR = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_UPLOAD_ERROR_F
 */
const UPLOAD_ERR_CANT_WRITE = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_UPLOAD_ERROR_X
 */
const UPLOAD_ERR_EXTENSION = UNKNOWN;
#ifdef ZEND_VERIFY_TYPE_INFERENCE
/**
 * @var bool
 * @cvalue ZEND_VERIFY_TYPE_INFERENCE
 */
const ZEND_VERIFY_TYPE_INFERENCE = UNKNOWN;
#endif
/**
 * @var string
 * @cvalue sapi_module.name
 * @no-file-cache
 */
const PHP_SAPI = UNKNOWN;
/**
 * @var string
 * @cvalue PG(php_binary) ? PG(php_binary) : ""
 * @no-file-cache
 */
const PHP_BINARY = UNKNOWN;
